@@ -37,7 +37,7 @@
  * This prog outputs several defines:
  *
  *	HAVE_FILEPOS_SCALAR
- *		defined ==> ok to perform arithmetic ops, = and comparisons
+ *		defined ==> OK to perform arithmetic ops, = and comparisons
  *		undefined ==> convert to ZVALUE first
  */
 
@@ -69,7 +69,7 @@ main(void)
 	if (value > (FILEPOS)1) {
 		--value;
 	}
-#if !defined(_WIN32)
+#if !defined(_WIN32) && !defined(_WIN64)
 	if (value <= (FILEPOS)getppid()) {
 		--value;
 	}
