@@ -1,7 +1,7 @@
 /*
  * lib_calc - calc link library initialization and shutdown routines
  *
- * Copyright (C) 1999-2007,2018,2021  Landon Curt Noll
+ * Copyright (C) 1999-2007,2018,2021,2022  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -94,6 +94,7 @@ typedef struct {int fd;} ttystruct;
 #endif /* Windows */
 
 
+#include "attribute.h"
 #include "banned.h"	/* include after system header <> includes */
 
 
@@ -500,7 +501,7 @@ initenv(void)
 	if (strlen(calcrc) > MAX_CALCRC) {
 		math_error("The $CALCRC variable is longer than %d chars",
 			   MAX_CALCRC);
-		/*NOTREACHED*/
+		not_reached();
 	}
 
 	/* determine the $CALCBINDINGS value */
@@ -542,7 +543,7 @@ initenv(void)
 	/* paranoia */
 	if (home == NULL) {
 		math_error("Unable to allocate string for $HOME");
-		/*NOTREACHED*/
+		not_reached();
 	}
 
 	/* determine the $PAGER value */
